==> estateplat-common-1.2.4-20190521.133707-163-sources.jar: cn/gtmap/estateplat/model/register/QlrModel.java <==
package cn.gtmap.estateplat.model.register;

import java.io.Serializable;

/**
 * @author <a href="mailto:zhangxing@gtmap.cn">zx</a>
 * @version 1.0,
 * @description 外网申报登记权利人模型
 */
public class QlrModel implements Serializable {
    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 权利人ID
     */
    private String qlrid;

    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 申请ID
     */
    private String sqid;

    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 权利人名称
     */
    private String qlrmc;

    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 权利人身份证件种类
     */
    private String qlrsfzjzl;

    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 权利人证件号
     */
    private String qlrzjh;

    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 权利人通讯地址
     */
    private String qlrtxdz;

    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 权利人类型
     */
    private String qlrlx;

    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 权利比例
     */
    private String qlbl;

    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 权利人联系电话
     */
    private String qlrlxdh;

    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 适用于组合登记类型，比如“预购商品房预告、抵押权预告登记”；字典项
     */
    private String zdjlx;

    private String zdjlxmc;

    private String zjlx;


    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 代理人电话
     */
    private String dlrdh;

    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 代理人名称
     */
    private String dlrmc;

    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 法定代表人或负责人电话
     */
    private String fddbrhfzrdh;


    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 法定代表人或负责人
     */
    private String fddbrhfzr;


    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @version 1.0,
     * @description 性别
     */
    private String xb;

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @version 1.0,
     * @description 代理人证件种类
     */
    private String qlrdlrzjzl; //代理人证件种类

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @version 1.0,
     * @description 代理人证件号
     */
    private String qlrdlrzjh; //代理人证件号


    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @version 1.0,
     * @description 权利类型
     */
    private String qllx; //权利类型

    private String lzrmc;//领证人名称
    private String lzrsfzjzl ;//领证人身份证件种类
    private String lzrzjh ;//领证人证件号
    private String gyfs ;//共有方式



    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getQlrdlrzjh() {
        return qlrdlrzjh;
    }

    public void setQlrdlrzjh(String qlrdlrzjh) {
        this.qlrdlrzjh = qlrdlrzjh;
    }

    public String getQlrdlrzjzl() {
        return qlrdlrzjzl;
    }

    public void setQlrdlrzjzl(String qlrdlrzjzl) {
        this.qlrdlrzjzl = qlrdlrzjzl;
    }

    public String getZdjlxmc() {
        return zdjlxmc;
    }

    public void setZdjlxmc(String zdjlxmc) {
        this.zdjlxmc = zdjlxmc;
    }

    public String getZjlx() {
        return zjlx;
    }

    public void setZjlx(String zjlx) {
        this.zjlx = zjlx;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid == null ? null : qlrid.trim();
    }

    public String getSqid() {
        return sqid;
    }

    public void setSqid(String sqid) {
        this.sqid = sqid == null ? null : sqid.trim();
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc == null ? null : qlrmc.trim();
    }

    public String getQlrsfzjzl() {
        return qlrsfzjzl;
    }

    public void setQlrsfzjzl(String qlrsfzjzl) {
        this.qlrsfzjzl = qlrsfzjzl == null ? null : qlrsfzjzl.trim();
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh == null ? null : qlrzjh.trim();
    }

    public String getQlrtxdz() {
        return qlrtxdz;
    }

    public void setQlrtxdz(String qlrtxdz) {
        this.qlrtxdz = qlrtxdz == null ? null : qlrtxdz.trim();
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx == null ? null : qlrlx.trim();
    }

    public String getQlbl() {
        return qlbl;
    }

    public void setQlbl(String qlbl) {
        this.qlbl = qlbl == null ? null : qlbl.trim();
    }

    public String getQlrlxdh() {
        return qlrlxdh;
    }

    public void setQlrlxdh(String qlrlxdh) {
        this.qlrlxdh = qlrlxdh == null ? null : qlrlxdh.trim();
    }

    public String getZdjlx() {
        return zdjlx;
    }

    public void setZdjlx(String zdjlx) {
        this.zdjlx = zdjlx == null ? null : zdjlx.trim();
    }

    public String getDlrdh() {
        return dlrdh;
    }

    public void setDlrdh(String dlrdh) {
        this.dlrdh = dlrdh== null ? null : dlrdh.trim();
    }

    public String getDlrmc() {
        return dlrmc;
    }

    public void setDlrmc(String dlrmc) {
        this.dlrmc = dlrmc== null ? null : dlrmc.trim();
    }

    public String getFddbrhfzrdh() {
        return fddbrhfzrdh;
    }

    public void setFddbrhfzrdh(String fddbrhfzrdh) {
        this.fddbrhfzrdh = fddbrhfzrdh == null ? null : fddbrhfzrdh.trim();
    }

    public String getFddbrhfzr() {
        return fddbrhfzr;
    }

    public void setFddbrhfzr(String fddbrhfzr) {
        this.fddbrhfzr = fddbrhfzr == null ? null : fddbrhfzr.trim();
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getLzrmc() {
        return lzrmc;
    }

    public void setLzrmc(String lzrmc) {
        this.lzrmc = lzrmc;
    }

    public String getLzrsfzjzl() {
        return lzrsfzjzl;
    }

    public void setLzrsfzjzl(String lzrsfzjzl) {
        this.lzrsfzjzl = lzrsfzjzl;
    }

    public String getLzrzjh() {
        return lzrzjh;
    }

    public void setLzrzjh(String lzrzjh) {
        this.lzrzjh = lzrzjh;
    }

    public String getGyfs() {
        return gyfs;
    }

    public void setGyfs(String gyfs) {
        this.gyfs = gyfs;
    }

    @Override
    public String toString() {
        return "Qlr{" +
                "qlrid='" + qlrid + '\'' +
                ", sqid='" + sqid + '\'' +
                ", qlrmc='" + qlrmc + '\'' +
                ", xb='" + xb + '\'' +
                ", qlrsfzjzl='" + qlrsfzjzl + '\'' +
                ", qlrzjh='" + qlrzjh + '\'' +
                ", qlrtxdz='" + qlrtxdz + '\'' +
                ", qlrlx='" + qlrlx + '\'' +
                ", qlbl='" + qlbl + '\'' +
                ", qlrlxdh='" + qlrlxdh + '\'' +
                ", zdjlx='" + zdjlx + '\'' +
                ", zdjlxmc='" + zdjlxmc + '\'' +
                ", zjlx='" + zjlx + '\'' +
                ", dlrdh='" + dlrdh + '\'' +
                ", dlrmc='" + dlrmc + '\'' +
                ", fddbrhfzrdh='" + fddbrhfzrdh + '\'' +
                ", fddbrhfzr='" + fddbrhfzr + '\'' +
                ", lzrmc='" + lzrmc + '\'' +
                ", lzrsfzjzl='" + lzrsfzjzl + '\'' +
                ", lzrzjh='" + lzrzjh + '\'' +
                ", gyfs='" + gyfs + '\'' +
                '}';
    }
}

==> estateplat-common-1.2.4-20190709.091827-195-sources.jar: cn/gtmap/estateplat/model/register/QlrModel.java <==
package cn.gtmap.estateplat.model.register;

import java.io.Serializable;

/**
 * @author <a href="mailto:zhangxing@gtmap.cn">zx</a>
 * @version 1.0,
 * @description 外网申报登记权利人模型
 */
public class QlrModel implements Serializable {
    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 权利人ID
     */
    private String qlrid;

    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 申请ID
     */
    private String sqid;

    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 权利人名称
     */
    private String qlrmc;

    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 权利人身份证件种类
     */
    private String qlrsfzjzl;

    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 权利人证件号
     */
    private String qlrzjh;

    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 权利人通讯地址
     */
    private String qlrtxdz;

    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 权利人类型
     */
    private String qlrlx;

    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 权利比例
     */
    private String qlbl;

    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 权利人联系电话
     */
    private String qlrlxdh;

    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 适用于组合登记类型，比如“预购商品房预告、抵押权预告登记”；字典项
     */
    private String zdjlx;

    private String zdjlxmc;

    private String zjlx;


    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 代理人电话
     */
    private String dlrdh;

    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 代理人名称
     */
    private String dlrmc;

    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 法定代表人或负责人电话
     */
    private String fddbrhfzrdh;


    /**
     * @author <a href="mailto:zhangyu2@gtmap.cn">zhangyu2</a>
     * @version 1.0,
     * @description 法定代表人或负责人
     */
    private String fddbrhfzr;


    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @version 1.0,
     * @description 性别
     */
    private String xb;

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @version 1.0,
     * @description 代理人证件种类
     */
    private String qlrdlrzjzl; //代理人证件种类

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @version 1.0,
     * @description 代理人证件号
     */
    private String qlrdlrzjh; //代理人证件号


    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @version 1.0,
     * @description 权利类型
     */
    private String qllx; //权利类型

    private String lzrmc;//领证人名称
    private String lzrsfzjzl ;//领证人身份证件种类
    private String lzrzjh ;//领证人证件号
    private String gyfs ;//共有方式
    private Integer sxh;//顺序号

    public Integer getSxh() {
        return sxh;
    }

    public void setSxh(Integer sxh) {
        this.sxh = sxh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getQlrdlrzjh() {
        return qlrdlrzjh;
    }

    public void setQlrdlrzjh(String qlrdlrzjh) {
        this.qlrdlrzjh = qlrdlrzjh;
    }

    public String getQlrdlrzjzl() {
        return qlrdlrzjzl;
    }

    public void setQlrdlrzjzl(String qlrdlrzjzl) {
        this.qlrdlrzjzl = qlrdlrzjzl;
    }

    public String getZdjlxmc() {
        return zdjlxmc;
    }

    public void setZdjlxmc(String zdjlxmc) {
        this.zdjlxmc = zdjlxmc;
    }

    public String getZjlx() {
        return zjlx;
    }

    public void setZjlx(String zjlx) {
        this.zjlx = zjlx;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid == null ? null : qlrid.trim();
    }

    public String getSqid() {
        return sqid;
    }

    public void setSqid(String sqid) {
        this.sqid = sqid == null ? null : sqid.trim();
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc == null ? null : qlrmc.trim();
    }

    public String getQlrsfzjzl() {
        return qlrsfzjzl;
    }

    public void setQlrsfzjzl(String qlrsfzjzl) {
        this.qlrsfzjzl = qlrsfzjzl == null ? null : qlrsfzjzl.trim();
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh == null ? null : qlrzjh.trim();
    }

    public String getQlrtxdz() {
        return qlrtxdz;
    }

    public void setQlrtxdz(String qlrtxdz) {
        this.qlrtxdz = qlrtxdz == null ? null : qlrtxdz.trim();
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx == null ? null : qlrlx.trim();
    }

    public String getQlbl() {
        return qlbl;
    }

    public void setQlbl(String qlbl) {
        this.qlbl = qlbl == null ? null : qlbl.trim();
    }

    public String getQlrlxdh() {
        return qlrlxdh;
    }

    public void setQlrlxdh(String qlrlxdh) {
        this.qlrlxdh = qlrlxdh == null ? null : qlrlxdh.trim();
    }

    public String getZdjlx() {
        return zdjlx;
    }

    public void setZdjlx(String zdjlx) {
        this.zdjlx = zdjlx == null ? null : zdjlx.trim();
    }

    public String getDlrdh() {
        return dlrdh;
    }

    public void setDlrdh(String dlrdh) {
        this.dlrdh = dlrdh== null ? null : dlrdh.trim();
    }

    public String getDlrmc() {
        return dlrmc;
    }

    public void setDlrmc(String dlrmc) {
        this.dlrmc = dlrmc== null ? null : dlrmc.trim();
    }

    public String getFddbrhfzrdh() {
        return fddbrhfzrdh;
    }

    public void setFddbrhfzrdh(String fddbrhfzrdh) {
        this.fddbrhfzrdh = fddbrhfzrdh == null ? null : fddbrhfzrdh.trim();
    }

    public String getFddbrhfzr() {
        return fddbrhfzr;
    }

    public void setFddbrhfzr(String fddbrhfzr) {
        this.fddbrhfzr = fddbrhfzr == null ? null : fddbrhfzr.trim();
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getLzrmc() {
        return lzrmc;
    }

    public void setLzrmc(String lzrmc) {
        this.lzrmc = lzrmc;
    }

    public String getLzrsfzjzl() {
        return lzrsfzjzl;
    }

    public void setLzrsfzjzl(String lzrsfzjzl) {
        this.lzrsfzjzl = lzrsfzjzl;
    }

    public String getLzrzjh() {
        return lzrzjh;
    }

    public void setLzrzjh(String lzrzjh) {
        this.lzrzjh = lzrzjh;
    }

    public String getGyfs() {
        return gyfs;
    }

    public void setGyfs(String gyfs) {
        this.gyfs = gyfs;
    }

    @Override
    public String toString() {
        return "QlrModel{" +
                "qlrid='" + qlrid + '\'' +
                ", sqid='" + sqid + '\'' +
                ", qlrmc='" + qlrmc + '\'' +
                ", qlrsfzjzl='" + qlrsfzjzl + '\'' +
                ", qlrzjh='" + qlrzjh + '\'' +
                ", qlrtxdz='" + qlrtxdz + '\'' +
                ", qlrlx='" + qlrlx + '\'' +
                ", qlbl='" + qlbl + '\'' +
                ", qlrlxdh='" + qlrlxdh + '\'' +
                ", zdjlx='" + zdjlx + '\'' +
                ", zdjlxmc='" + zdjlxmc + '\'' +
                ", zjlx='" + zjlx + '\'' +
                ", dlrdh='" + dlrdh + '\'' +
                ", dlrmc='" + dlrmc + '\'' +
                ", fddbrhfzrdh='" + fddbrhfzrdh + '\'' +
                ", fddbrhfzr='" + fddbrhfzr + '\'' +
                ", xb='" + xb + '\'' +
                ", qlrdlrzjzl='" + qlrdlrzjzl + '\'' +
                ", qlrdlrzjh='" + qlrdlrzjh + '\'' +
                ", qllx='" + qllx + '\'' +
                ", lzrmc='" + lzrmc + '\'' +
                ", lzrsfzjzl='" + lzrsfzjzl + '\'' +
                ", lzrzjh='" + lzrzjh + '\'' +
                ", gyfs='" + gyfs + '\'' +
                ", sxh='" + sxh + '\'' +
                '}';
    }
}
